PI GCS python wrapper
=======================

A python wrapper around Physik Instrument General Command Set API.

----

The PI GCS2 library is distributed by PI. This is a Python wrapper around the GCS2 library

Should run on python3

